#
# spec file for package sonic-visualiser
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 Tom Mbrt <tom.mbrt@googlemail.com>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2011 Evstifeev Roman <someuniquename@gmail.com>
# Copyright (c) 2005-2010 oc2pus <oc2pus@arcor.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#%%define urlcode 2786
Name:           sonic-visualiser
Version:        5.0
Release:        1.1
Summary:        A program for viewing and analysing contents of audio files
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://www.sonicvisualiser.org/
#Source:         https://code.soundsoftware.ac.uk/attachments/download/%%{urlcode}/%%{name}-%%{version}.tar.gz
Source0:        https://github.com/sonic-visualiser/sonic-visualiser/releases/download/sv_v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.xml
# PATCH-FIX-OPENSUSE sonic-visualiser-system-dataquay.patch aloisio@gmx.com -- force use of system libdataquay
Patch0:         sonic-visualiser-system-dataquay.patch
BuildRequires:  capnproto
BuildRequires:  dssi
BuildRequires:  flac
%if 0%{?is_opensuse} && 0%{?suse_version} <= 1600
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Platform)
BuildRequires:  pkgconfig(Qt6Svg)
BuildRequires:  pkgconfig(Qt6Test)
BuildRequires:  pkgconfig(Qt6Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(capnp)
%if 0%{?BUILD_ORIG}
BuildRequires:  pkgconfig(dataquay) >= 0.9
%endif
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fishsound)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(id3tag)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(lrdf)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(oggz) >= 0.9.5
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(raptor2) >= 2.0.4
BuildRequires:  pkgconfig(rasqal)
BuildRequires:  pkgconfig(redland) >= 1.0.14
BuildRequires:  pkgconfig(rubberband)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(serd-0)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(sord-0)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(vamp-hostsdk) >= 2.10
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires:       dssi
Requires:       ladspa

%description
Sonic Visualiser is a program for viewing and analysing the contents
of music audio files.

With Sonic Visualiser you can:
* Load audio files in various formats and view their waveforms

* Look at audio visualisations such as spectrogram views, with
  interactive adjustment of display parameters

* Annotate audio data by adding labelled time points and defining
  segments, point values and curves

* Run feature-extraction plugins to calculate annotations
  automatically, using algorithms such as beat trackers, pitch
  detectors and so on

* Import annotation data from various text formats and MIDI files

* Play back the original audio with synthesised annotations, taking
  care to synchronise playback with the display position

* Slow down playback and loop segments of interest, including
  seamless looping of complex non-contiguous areas

* Export annotations and audio selections to external files.

* Sonic Visualiser can also be controlled remotely using the Open Sound
  Control (OSC) protocol

%prep
%setup -q
%if 0%{?BUILD_ORIG}
%patch -P 0 -p1
%endif

# required with capnproto 0.7.0
for x in *.pr* config* Makefile* ; do perl -i -p -e 's/c\+\+11/c++14/g' "$x" ; done

# Don't use -Werror on releases
find . -name configure -o -name "*.pro" -o -name "*.pri" -exec sed -i s'# -Werror##g' {} \;

# fix arch lib dir
sed -e 's|/usr/lib/|/usr/%{_lib}/|g;s|/usr/local/lib/|/usr/local/%{_lib}/|g' \
    -i checker/src/knownplugins.cpp svcore/system/System.h \
       vamp-plugin-sdk/src/vamp-hostsdk/PluginHostAdapter.cpp

%build
export LC_ALL=en_US.UTF-8
%if 0%{?is_opensuse} && 0%{?suse_version} <= 1600
export CC=gcc-12 CXX=g++-12
%endif
%meson
%meson_build

%install
%meson_install

# fix executable bit for helper programs
chmod +x %{buildroot}%{_bindir}/*vamp-*

# plugin dir
install -dm 755 %{buildroot}%{_libdir}/vamp

# icon
for size in 16 22 24 32 48 64 128 ; do
install -Dm 644 icons/sv-${size}x${size}.png %{buildroot}/%{_datadir}/icons/hicolor/${size}x${size}/apps/%{name}.png
done

install -Dm 644 icons/sv-icon.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
ln -s sonic-visualiser.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/sv-icon.svg

# mime types
install -Dm 644 %{SOURCE1} %{buildroot}%{_datadir}/mime/packages/%{name}.xml
install -Dm 644 x-sonicvisualiser.desktop %{buildroot}/%{_datadir}/mimelnk/application/x-sonicvisualiser.desktop
install -Dm 644 x-sonicvisualiser-layer.desktop %{buildroot}/%{_datadir}/mimelnk/application/x-sonicvisualiser-layer.desktop

# Menu
%suse_update_desktop_file -i %{name} AudioVideo Audio Music

%post
%{_bindir}/update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
%{_bindir}/update-mime-database %{_datadir}/mime &> /dev/null || :

%files
%doc CHANGELOG README.md
%license COPYING
%{_bindir}/%{name}
%{_bindir}/piper-convert
%{_bindir}/piper-vamp-simple-server
%{_bindir}/vamp-plugin-load-checker
%dir %{_libdir}/vamp
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/scalable/apps/sv-icon.svg
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application
%{_datadir}/mimelnk/application/x-sonicvisualiser*

%changelog
* Sat Sep  7 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Use gcc-12 for Leap 15.6
- Update to 5.0
  * Port to Qt6. The code now builds only with Qt6, and Qt5 is no
    longer supported
  * Add mechanism to ignore plugins on subsequent runs if they fail to
    load, and to review ignored plugins from the preferences dialog
  * Add Mel scale to the options for vertical spectrogram scale
  * Add an opaque toggle to the spectrogram; switching it off gives
    spectrograms some transparency, so they can be overlaid over other
    layers, including other spectrograms
  * Update opaque toggle in colour 3d layers so that it works like the
    new one in the spectrogram. Previously colour 3d plot layers could
    be translucent at low resolutions but not at higher ones; now the
    setting affects all resolutions. Correspondingly make it default to
    off, as in the spectrogram
  * Add smoothing toggle directly to spectrogram parameters, like the
    one already found in colour 3d plot layers. Previously spectrogram
    smoothing could be toggled only from the preferences
  * Stop snapping spectrogram frequency range to bin frequencies. This
    already-confusing feature caused problems with the new support for
    translucent spectrograms, which permits overlaying spectrograms of
    differing bin counts that would be too hard to line up properly if
    the frequency extents were always snapped to the nearest bin
  * Clarify keyboard and mouse shortcut descriptions in the Key And
    Mouse Reference window, especially for the platform-specific
    descriptions used on the Mac, and add a few more alternative
    shortcuts including more standard zoom in/out shortcuts
  * Fix disappearing peaks in peak-bin display mode in the spectrogram,
    caused by overzealous smoothing
  * Fix jumps in spectrogram when changing zoom level between certain
    values in hi-dpi pixel-doubled situations, caused by a failure of
    cache invalidation
  * Fix some very slow spectrogram painting
  * Fix disappearance of right-button Transforms menu after file load
  * Fix inconsistent default vs set threshold values in spectrogram
  * Fix crash on painting very low-resolution dense 3d plots
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jun 22 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 4.5.2
- Remove sonic-visualiser-Fix-build-failure.patch as fixed in upstream
- Use system vamp host sdk
  * Support multi-line text labels on time instants
  * Improve refresh and rendering of text labels in various layers
  * Improve abbreviation of layer names in the key at bottom-right of a
    pane
  * Fix repeated writes to settings file when rendering time-ruler
    layers at close zoom levels
  * Use system Vamp host SDK if provided
- Changes in 4.5.1
  * Update to use Rubber Band v3 with its higher quality timestretcher
    (the older, lower-CPU one is still available in preferences). This
    means the build requires rubberband-3.0.0 or newer, so you may need
    to install it separately if building on an older system.
  * Fix inability to select Hz as the unit of a layer following import
  * Provisional fix to bailing out on startup when invoked with "Open
    With..." on Mac
  * Fix nonsense display when showing frequency scaled points with value
    of 0Hz
* Tue Oct 25 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Add patch sonic-visualiser-Fix-build-failure.patch
* Thu Apr 14 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- copypac from home:munix9
- changes in versio 4.5:
  * Add option to switch off the interpolation used in the waveform
    view for zoom levels closer than one pixel per frame: sometimes it
    can be an unnecessary distraction. With interpolation switched off,
    the individual samples are shown as unconnected points instead
  * Make it possible to toggle segment colouring in the segmentation
    view of the time value layer, as well as toggling segment division
    lines
  * When importing CSV files, if a column heading indicates a likely
    unit for the column, use it by default; also remember last user
    settings for the import dialog
  * Ensure the Choose Default Template option on the templates menu can
    be reached even when no file is loaded
  * Give the spectrum layer the same effective scale range as it had
    before the dB scale fix in v4.4, fixing the accidental halving of
    the visible range for that layer in v4.4
  * Fix hang when opening two plugin parameter dialogs at once
  * Fix crash when rendering slice or spectrum layers scrolled to
    earlier than the start of the audio or later than the end
  * Fix crash when more than one audio file is supplied at the command
    line with a default session template that requires regenerating one
    or more feature extraction layers and layer generation produces an
    error or warning
  * Fix failure to exit fully if the window is closed before plugin
    scan is complete at startup
* Thu Mar 31 2022 munix9@googlemail.com
- update to version 4.5
* Sun Mar 28 2021 Luigi Baldoni <aloisio@gmx.com>
- Remove download URL from Source line due to certificate
  troubles
* Fri Mar 26 2021 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 4.3
  * Fix failure to activate the Align button on startup, even when the
  appropriate alignment plugin is installed
  * Fix (obviously) incorrect colour display for closely zoomed-in
  colour 3d plot views
  * Switch the build system from autoconf/qmake/make to meson/ninja
* Fri Jan  1 2021 Luigi Baldoni <aloisio@gmx.com>
- Actually remove 0001-Fix-build-with-Qt-5.15.patch
- Set correct download URL
* Thu Dec 31 2020 Edgar Aichinger <edogawa@aon.at>
- Update to 4.2
- Remove 0001-Fix-build-with-Qt-5.15.patch (fixed upstream)
* Sat Jun  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
* Tue Jan 28 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.0.1
  * Fix the vertical scale in NoteLayer when displaying a model
    with non-Hz scale
  * Fix failure to make installed executables executable when
  compiling and installing the source package
- Remove conditions for unmaintained openSUSE versions.
- Don't use -Werror.
* Thu Oct 31 2019 Edgar Aichinger <edogawa@aon.at>
- Update to version 4.0
  * Add Box annotation layer type, typically used for time-frequency boxes
  to be annotated over a spectrogram. Because this introduces a new layer
  type into the session file format, the major version number has been
  bumped to v4.0. Sessions saved from v4.0 can still be opened in earlier
  versions of Sonic Visualiser, but any Box layers will not be loaded
  * Fix behaviour of auto-align layers on top of waveform: they can now be
  aligned in the vertical scale, if they have a unit of V and the waveform
  is of a single channel in linear or dB mode
  * Make the UI more readable in macOS "dark mode"
  * Fix sluggishness in starting and stopping playback when using PulseAudio
  v13.0+
  Changes in version 3.3
  * Add support for reading the Opus audio codec on all platforms
  * Add support for WMA and AAC formats on 64-bit Windows. (AAC was already
  supported on macOS.) Note that AAC support on Windows does not support
  "gapless" import, i.e. removing the encoder gaps at start and end of
  the stream
  * Add ability to choose the field separator when importing CSV and
  CSV-like files, if more than one possible candidate separator is
  found in the file
  * Fix crash when closing session or starting a new session while
  calculating alignment of multiple audio files
  * Fix crash when running certain plugins that call for frequency-domain
  input at non-power-of-two block sizes
  * Fix wandering left edge of measure-tool rectangle while dragging out
  the area
  * Ensure that plugin stderr debug output is logged to the SV log file
- Refreshed sonic-visualiser-system-dataquay.patch
* Wed Jan 30 2019 Konstantin Voinov <kill_it@mail.ru>
- Update to version 3.2.1
  * Fix failure to record from built-in microphone on macOS 10.14
  (caused by lack of microphone permission request text)
  * Fix crash when closing SV or starting a new session during recording
  * Fix crash on exit in some builds that disable OSC support
  * Fix flashing effect when scrolling certain configurations of colour 3d
  plot layer leftwards
  Changes in version 3.2
  * Add ability to zoom closer than one sample per pixel, so as to see
  the interpolated signal level between samples
  * Add oversampling control to the spectrogram and spectrum layers
  * Highlight and label frequency peaks in the spectrum as the mouse
  rolls over them, when enabled in the parameter area
  * Add feature to convert and import audio from a CSV data file
  * Add some new colour maps, and restore the old Blue on Black one
  * Speed up spectrum rendering at high resolutions
  * Fix failure to pass Nyquist bins correctly to
  frequency-domain-input Vamp plugins in some circumstances
  * Fix sometimes incorrect shortcut associations for new-layer menu
  items
  * Various other rendering improvements and bug fixes
- Refreshed sonic-visualiser-system-dataquay.patch
* Fri Oct 26 2018 Wolfgang Bauer <wbauer@tmo.at>
- Use gcc7 on Leap 42.3 to fix build
* Fri Oct 12 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.1.1
  * Fix failure to record correctly into an empty session with
    certain audio drivers
  * Fix failure to run LADSPA plugins at all, except with some
    unusual path layouts
  * Fix failure to silence sonified notes when rewinding backwards
    or jumping back from a loop endpoint
* Mon Aug  6 2018 aloisio@gmx.com
- Fixed the tests and dropped
  sonic-visualiser-remove-svcore-test.patch
* Tue Jul 17 2018 aloisio@gmx.com
- Update to version 3.1
  * Add Plugins tab to Preferences dialog, from which you can
    review the plugin load paths and see which plugins were
    loaded from which locations, and also customise load paths
    (though the various path environment variables are still
    supported)
  * Stream the export of audio data and other CSV data so that
    very large exports don't hang the UI or run us out of memory
    (thanks to Lucas Thompson)
  * Ensure vertical scale appears for auto-align layers when
    there is nothing else to auto-align them to
  * Fix another long-standing Windows-platform wide-char/utf8
    conversion problem, with environment variable naming and
    contents
  * Improve handling of incomplete session loads, i.e.
    situations where the audio files referred to by a session
    could not be found - previously the session could be re-saved
    immediately thus losing the audio reference; now at least we
    disable Save (enabling only Save As) and show a warning
  * Update pane and layer menu shortcuts so that the
    waveform/spectrogram/etc shortcuts (Shift+G etc) operate on
    the source model in the currently-selected pane rather than
    the main model. This is a backward-incompatible change but is
    a far more intuitive way for the function to work
  * Use dark background for bright colours in time-value/note/etc
    layers as well as e.g. waveforms - this is how it was always
    "intended to" work, but it is a backward-incompatible change
  * Make "Select All" select the whole span of everything that
    exists, not just the main model
  * Add horizontal scale to Spectrum layer
  * Improve spacing and labelling of vertical log scales
  * Update build system for better Cap'n Proto version support
    and to use Repoint for code management in the repository
  * Various other bug fixes
- Dropped piper.capnp (fixed upstream)
- Refreshed sonic-visualiser-remove-svcore-test.patch
- Added sonic-visualiser-system-dataquay.patch
- Spec cleanup
* Thu Sep 14 2017 aloisio@gmx.com
- Build against dataquay also in Tumbleweed
* Mon Aug 28 2017 aloisio@gmx.com
- Update to version 3.0.3
  * Improve decisions about where and how to label vertical scales
  * Update build support material and documentation to reflect the
    official release of Cap'n Proto 0.6 (which we can now use rather
    than depending on git builds)
  version 3.0.2:
  * Fix crash when changing parameters for spectrum view
  * Fix incorrect measure tool crosshairs in spectrum view
  * Update Russian and Czech UI translations (thanks to Alexandre
    Prokoudine and Pavel Fric respectively)
  version 3.0.1:
  * Update MIDI input driver layer
  version 3.0:
  * Add ability to record audio, and ability to change the audio
    device for playback or recording in the preferences
  * Add complete support for high-resolution (Hi-DPI or retina)
    displays, including for layer data rendering as well as UI
    controls and icons. This makes the biggest difference when using
    a retina Mac, on which previous versions did not render layer
    data at retina resolution, but it also improves scaling and
    rendering of UI elements on Hi-DPI displays on Windows and Linux
  * Add ability to export scalable (SVG) image files
  * Run plugins in a separate process, so that if a plugin crashes,
    it no longer brings down Sonic Visualiser with it. In every other
    respect the behaviour should be unchanged
  * Scan plugins on startup in a separate process, and report on any
    that crash or won't load
  * Add ability to open, display, and analyse very long audio files
    (of more than 2^32 sample frames)
  * Change mp3 file loading so as to compensate for encoder/decoder
    delay and padding (using "gapless playback" logic). While this
    is a real improvement, unfortunately it does mean that the
    initial padding in mp3 file load has changed from previous
    versions, which may mean some sessions saved in previous versions
    are no longer correctly aligned. It's not a great idea to use mp3
    as a file format of record, because of differences like this
    between decoders. The previous behaviour is still available as a
    preference.
  * Add new Hybrid normalisation type for spectrogram and colour 3d
    plot layers. This normalises each column to its peak value and
    then scales the normalised values by the log of the peak in order
    to restore some distinction in scale between columns with
    different levels. It can provide quite visually clear results.
  * Add function to subdivide time instant layers into regular
    intervals (and its inverse)
  * Add new preference for default colour scales
  * Add a basic ability to zoom (in the frequency axis) to the
    spectrum
  * Switch to using combined level/pan controls in layer property
    boxes and for the main volume control
  * Make CSV file reader better able to handle files with varying
    numbers of columns
  * Add "What's New" dialog
- Dropped sonic-visualiser-ld-X11-fix.patch and refreshed
  sonic-visualiser-remove-svcore-test.patch
- Added piper.capnp schema to generate sources without the
  hardcoded capnp 0.6.0
- Dropped sonic-visualiser.desktop
- Added fishsound requirement
* Fri Aug 25 2017 olaf@aepfle.de
- Remove mad conditional because it is always present
* Sat Jan  7 2017 aloisio@gmx.com
- Update to version 2.5
  * Add unit-converter dialog, for converting between various
    pitch and timing units
  * Fix failure to reload note layers from session file
  * Use a more sensible scale for the play-speed dial
  * Fix crash when importing very wide CSV files
  * Fix generation of wrong layer type from some CSV files
  * Fix failure to export last instant in a time-instant layer
  version 2.4:
  * Fix a crash when rendering certain colour 3d plot layers
  version 2.3:
  * Add support for left/right scrolling using a two-finger
    touchpad gesture (where available)
  * Make the octave numbering into a configurable option, and
    change the default. Previously Sonic Visualiser labelled
    middle-C as "C3"; now it labels middle-C as "C4", a more
    common standard in the world outside MIDI sequencer
    software. The previous system is available as an option
    in the Preferences. This affects only the visible
    labels: there is no change to analysis or to the file
    format
  * Sonify time-value layers. Any time-value curve whose scale
    unit is set to Hz will now acquire a playback toggle
    control; this control is off by default, but if it is
    switched on, the curve will be played back using a
    variable-frequency sound generator
  * Add support for playback of note layers with non-MIDI
    frequencies (formerly the note playback was limited to
    exact MIDI pitch)
  * Change the default playback sample for note layers from
    piano to an electric piano with sustain. The piano sample
    is still available, and any sessions saved using it should
    continue to use it
  * Add a cancel button for Vamp plugin processing: currently,
    cancelling a transform results in a part-complete layer
    rather than removing the results
  * Add keyboard shortcuts to cycle the current layer (in
    addition to the existing ones to cycle the current pane)
  * Fix various bugs related to layer ordering: layer tabs
    re-ordering themselves randomly when new layer added,
    layers being ordered randomly when saving and reloading
    a session
  * Fix incorrect interaction with non-Unicode usernames when
    creating temporary and template directories on Windows
  * Shade the start and end of the main audio file, to make
    them easier to see for files that start or end in silence
  * Speed up rendering and scrolling in time-value layers
  * Make it possible to import CSV files directly into Note
    layers by adding Pitch as a data type in the CSV file
    import dialog
  * Fix play pointer jump to wrong frame when clicking on row
    in the layer edit dialog
  * Fix problems with keyboard shortcuts when using Qt5 on
    OS/X. This is the first release in which the official
    builds use Qt5 for all platforms.
  version 2.2:
  * Add a startup welcome dialog that also explains what SV
    makes network connections for and allows user to forbid
    them
  * Add "Export Audio Data" feature
  * Show piano keyboard scale in note and time-value layers as
    well as spectrogram, where vertical scale is log Hz; also
    show numerical scale in note and region layers when not
    auto-aligned
  * Speed up CSV file import and avoid showing crazily wide
    window for CSV file format dialog when file has lots of
    columns
  * Fix incorrectly saved window geometry when exiting from
    maximised state
  * Reduce number of timer wakeups when idle
  * Add American English translation and make choice of
    translation into a preference (defaulting to system locale)
  * Permit installation to non-default location with Windows
    installer build
  version 2.1:
  * Build with support for hidpi ("retina") text on OS/X
  * Fix very slow analysis when using Ogg or FLAC files decoded
    via libsndfile
  * Fix inaccurate scale auto-align between time-value layers
    and others
  * Fix failure to open files specified on command line (or via
    Open With) on Windows
  * Reset cyclical counters and switch back to navigate mode
    when a new session is started
  version 2.0.1:
  * Fix incorrect handling of FixedSampleRate outputs (Vamp
    SDK fix)
  * Make it easier to see results from transforms that return
    a single point
  * Make labelling clearer on time-value layers
  * Add discrete-curve mode for time-value layers (for curves
    with gaps)
  * Update code to build against Qt5
  version  2.0:
  * Fix incorrect samplerate in reading m4a files on OS/X
  version 1.9:
  * Support 64-bit builds on OS/X (using CoreAudio instead of
    obsolete QuickTime audio file reader)
  * Simplify RDF reading and fix some bugs. Now requires
    Dataquay (http://breakfastquay.com/dataquay/) rather than
    using Redland directly. Release builds use Sord/Serd rather
    than Redland
  * Add a fullscreen mode on the F11 key
- Refreshed sonic-visualiser-ld-X11-fix.patch
- Removed gcc-4.7.patch
- Added sonic-visualiser-remove-svcore-test.patch
  sonic-visualiser.desktop and sonic-visualiser.xml
- Spec cleanup
* Mon Oct  6 2014 avvissu@yandex.ru
- Patch to fix build (gcc-4.7.patch)
* Wed Mar 14 2012 pascal.bleser@opensuse.org
- add bits to enable mp3 support with mad when built on Packman
* Wed Mar 14 2012 pascal.bleser@opensuse.org
- remove dependency on licenses, gone in 12.1
- reformat spec file, fix license tag to be compliant with SPDX
* Thu Oct 20 2011 someuniquename@gmail.com
- update to 1.9
* Wed May  5 2010 toni@links2linux.de
- update to 1.7.2
* Thu Oct 29 2009 toni@links2linux.de
- update to 1.7.1
- This release contains a small number of enhancements and bug fixes.
  For more information, please read the change log at:
  https://sourceforge.net/projects/sv1/files/sonic-visualiser/1.7.1/CHANGELOG/download
* Mon Oct 26 2009 toni@links2linux.de
- update to 1.7
- The main focus of this release is to improve editing of note and region layers.
  It can import MIDI files that use SMPTE timecode for event timing, and
  optionally display time in seconds and frames at various frame rates throughout.
  A crash on exit in Windows has been fixed, and a number of other bugfixes are
  included.
* Mon Mar 16 2009 toni@links2linux.de
- update to 1.5
* Thu Dec 11 2008 toni@links2linux.de
- update to 1.4
* Thu Jul 10 2008 toni@links2linux.de
- update to 1.3
- using new rubberband-1.2
- added PulseAudio output driver
* Sun Mar 23 2008 toni@links2linux.de
- rebuild with new vamp-plugin-sdk
* Wed Feb 20 2008 toni@links2linux.de
- update to 1.2
* Mon Dec 31 2007 toni@links2linux.de
- rebuild with new libraptor/vamp-sdk packages
* Sun Sep  9 2007 toni@links2linux.de
- openSUSE-10.3 build corrected BuildRequires
* Tue Jun  5 2007 toni@links2linux.de
- rebuild with libfishsound1 (0.8.0)
* Fri May 11 2007 toni@links2linux.de
- update to 1.0
* Tue Mar 20 2007 toni@links2linux.de
- update to 1.0pre3
- moved all vamp-plugins to seperate packages
- using vamp-plugin-sdk to build
- switched to portaudio-19
* Mon Jan  1 2007 toni@links2linux.de
- build SuSE-10.2, corrected BuildRequires
* Thu Sep 21 2006 toni@links2linux.de
- build for packman
* Sat May 27 2006 oc2pus@arcor.de 0.9-0.oc2pus.2
- rebuild for SuSE-10.1 (no dssi-devel)
* Sun May 21 2006 oc2pus@arcor.de 0.9-0.oc2pus.1
- Initial release 0.9
- added vamp-QM-plugin 1.0
- added vamp-aubio-plugin 0.3.0
- added vamp-mazurka-plugins
  download sources from http://sv.mazurka.org.uk and packaged as tar.bz2,
  added libmain.cpp and create a shared lib with allmazurka-plugins
